# logpyle: Time Series Logging (not just) for Simulation

[![CI](https://github.com/illinois-ceesd/logpyle/workflows/CI/badge.svg)](https://github.com/illinois-ceesd/logpyle/actions?query=workflow%3ACI+branch%3Amaster)
[![Documentation Status](https://readthedocs.org/projects/logpyle/badge/?version=latest)](https://logpyle.readthedocs.io/en/latest/?badge=latest)

`logpyle` is a Python package for time series logging (formerly part of the `pytools.log` and `datapyle` packages)
that uses SQLite under the hood and makes it easy to compare multiple runs.

* [Documentation](https://logpyle.readthedocs.io/en/latest/)
